Documentation
¶
Overview ¶
Package appserver implements the HTTP server, routing, and request handling.
Index ¶
- type Server
- func (s *Server) GetDataCached() (map[string]any, error)
- func (s *Server) GetDataRawCached() ([]byte, error)
- func (s *Server) HandleStaticFile(w http.ResponseWriter, r *http.Request, path, contentType string)
- func (s *Server) PreWarm()
- func (s *Server) ServeHTTP(w http.ResponseWriter, r *http.Request)
- func (s *Server) SystemService() *appsystem.SystemService
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
func (*Server) GetDataCached ¶
getDataCached returns parsed data.json — delegates to loadData().
func (*Server) GetDataRawCached ¶
getDataRawCached returns cached data.json bytes — delegates to loadData().
func (*Server) HandleStaticFile ¶
HandleStaticFile serves an allowlisted file from the dashboard directory.
func (*Server) PreWarm ¶
func (s *Server) PreWarm()
PreWarm runs refresh.sh once in the background at startup so data.json is ready before the first browser request arrives.
func (*Server) SystemService ¶
func (s *Server) SystemService() *appsystem.SystemService
Click to show internal directories.
Click to hide internal directories.